import { task } from '../../task.js';
task('provision:app', async ({ host, $: root$ }) => {
    const $ = root$.with({ become: 'webpod' });
    const scripts = await host.scripts;
    if (!scripts.length)
        return;
    if (!await root$.test `pm2 --version`) {
        await root$ `npm i -g pm2@5.3.0`;
        await root$ `pm2 startup`;
    }
    const ports = JSON.parse((await $ `cat /home/webpod/.webpod/ports.json || echo '{}'`).toString());
    const exports = { apps: [] };
    for (const cmd of scripts) {
        const portsKey = await host.domain + '/' + cmd;
        const port = ports[portsKey] ?? randomPort();
        ports[portsKey] = port;
        const [script, args] = cmd.split(' ', 2);
        exports.apps.push({
            name: await host.domain,
            script,
            args,
            cwd: await host.currentPath,
            interpreter: await host.nodePath,
            instances: 'max',
            exec_mode: 'cluster',
            env: {
                PORT: port,
                NODE_ENV: 'production',
            },
        });
    }
    await $ `echo ${'module.exports = ' + JSON.stringify(exports, null, 2)} > ${host.deployPath}/apps.config.js`;
    await $ `echo ${JSON.stringify(ports, null, 2)} > /home/webpod/.webpod/ports.json`;
});
function randomPort() {
    return Math.floor(Math.random() * 10000) + 10000;
}
